summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/sourcefile.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /kdevdesigner/designer/sourcefile.cpp
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdevdesigner/designer/sourcefile.cpp')
-rw-r--r--kdevdesigner/designer/sourcefile.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kdevdesigner/designer/sourcefile.cpp b/kdevdesigner/designer/sourcefile.cpp
index 8e103e85..5b21afa5 100644
--- a/kdevdesigner/designer/sourcefile.cpp
+++ b/kdevdesigner/designer/sourcefile.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -122,7 +122,7 @@ bool SourceFile::saveAs( bool ignoreModified )
TQString old = filename;
TQString initFn = pro->makeAbsolute( filename );
if ( ignoreModified ) {
- TQString dir = TQStringList::split( ':', project()->iFace()->customSetting( "QTSCRIPT_PACKAGES" ) ).first();
+ TQString dir = TQStringList::split( ':', project()->iFace()->customSetting( "TQTSCRIPT_PACKAGES" ) ).first();
initFn = TQFileInfo( initFn ).fileName();
initFn.prepend( dir + "/" );
}
@@ -138,12 +138,12 @@ bool SourceFile::saveAs( bool ignoreModified )
pro->setModified( TRUE );
timeStamp.setFileName( pro->makeAbsolute( filename ) );
if ( ed )
- ed->setCaption( i18n( "Edit %1" ).arg( filename ) );
+ ed->setCaption( i18n( "Edit %1" ).tqarg( filename ) );
setModified( TRUE );
if ( pro->isDummy() ) {
- TQObject *o = ed->parent();
+ TQObject *o = ed->tqparent();
while ( o && !o->isA( "MainWindow" ) )
- o = o->parent();
+ o = o->tqparent();
if ( o )
((MainWindow *)o)->addRecentlyOpenedFile( fn );
}
@@ -187,10 +187,10 @@ TQString SourceFile::createUnnamedFileName( const TQString &extension )
extensionCounter = new TQMap<TQString, int>;
int count = -1;
TQMap<TQString, int>::Iterator it;
- if ( ( it = extensionCounter->find( extension ) ) != extensionCounter->end() ) {
+ if ( ( it = extensionCounter->tqfind( extension ) ) != extensionCounter->end() ) {
count = *it;
++count;
- extensionCounter->replace( extension, count );
+ extensionCounter->tqreplace( extension, count );
} else {
count = 1;
extensionCounter->insert( extension, count );
@@ -220,7 +220,7 @@ bool SourceFile::closeEvent()
ed->save();
switch ( TQMessageBox::warning( MainWindow::self, i18n( "Save Code" ),
- i18n( "Save changes to '%1'?" ).arg( filename ),
+ i18n( "Save changes to '%1'?" ).tqarg( filename ),
i18n( "&Yes" ), i18n( "&No" ), i18n( "&Cancel" ), 0, 2 ) ) {
case 0: // save
if ( !save() )
@@ -263,9 +263,9 @@ void SourceFile::checkTimeStamp()
if ( timeStamp.isUpToDate() )
return;
timeStamp.update();
- if ( TQMessageBox::information( MainWindow::self, i18n( "Qt Designer" ),
- i18n( "File '%1' has been changed outside Qt Designer.\n"
- "Do you want to reload it?" ).arg( filename ),
+ if ( TQMessageBox::information( MainWindow::self, i18n( "TQt Designer" ),
+ i18n( "File '%1' has been changed outside TQt Designer.\n"
+ "Do you want to reload it?" ).tqarg( filename ),
i18n( "&Yes" ), i18n( "&No" ) ) == 0 ) {
load();
if ( ed )
@@ -279,7 +279,7 @@ bool SourceFile::checkFileName( bool allowBreak )
if ( sf )
TQMessageBox::warning( MainWindow::self, i18n( "Invalid Filename" ),
i18n( "The project already contains a source file with \n"
- "filename '%1'. Please choose a new filename." ).arg( filename ) );
+ "filename '%1'. Please choose a new filename." ).tqarg( filename ) );
while ( sf ) {
LanguageInterface *iface = MetaDataBase::languageInterface( pro->language() );
TQString filter;
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the